@@ -472,8 +472,8 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 	char *ftoken = NULL;
 	bool bm = false;
 	bool first = true;
-	unsigned long addPmask = 0, subPmask = ~0;
-	unsigned long addPmask1 = 0, subPmask1 = ~0;
+	unsigned long addPmask = 0, subPmask = (unsigned long)~0;
+	unsigned long addPmask1 = 0, subPmask1 = (unsigned long)~0;
 	char catchname[256];
 
 	buffer = (char *)malloc(512);
@@ -537,7 +537,7 @@ compile:
 	addPmask1 = addPmask;
 	subPmask1 = subPmask;
 	addPmask = 0;
-	subPmask = ~0;
+	subPmask = (unsigned long)~0;
 
 	if(!first)
 		script->next = index[key];
@@ -1072,7 +1072,7 @@ repname1:
 	script->mask &= subPmask1;
 
 	addPmask1 = 0;
-	subPmask1 = ~0;
+	subPmask1 = (unsigned long)~0;
 	while(line)
 	{
 		line->mask &= script->mask;
