@@ -57,6 +57,11 @@ Mutex(), ScriptSymbols()
 	setString(logname, sizeof(logname), "ccscript");
 }
 
+unsigned ScriptInterp::getTempSize(void)
+{
+	return symsize + 1;
+}
+
 char *ScriptInterp::getTemp(void)
 {
 	char *tmp = temps[tempidx++];
